@@ -113,10 +113,15 @@ define!({
 
     pub struct QualifiedRule {
         pub span: Span,
-        pub prelude: SelectorList,
+        pub prelude: QualifiedRulePrelude,
         pub block: SimpleBlock,
     }
 
+    pub enum QualifiedRulePrelude {
+        SelectorList(SelectorList),
+        Invalid(Tokens),
+    }
+
     pub enum StyleBlock {
         AtRule(AtRule),
         Declaration(Declaration),
@@ -473,9 +478,7 @@ define!({
 
     pub enum Rule {
         QualifiedRule(QualifiedRule),
-
         AtRule(AtRule),
-
         Invalid(Tokens),
     }
 
